API Reference
=============

.. toctree::
   :maxdepth: 1

   metric
   christoffel
   riemann
   ricci
   einstein
   weyl
   schouten
   kretschner
   geodesic
   stress_energy
   indexing
   metrics
   display
   check
   simplify
